@@ -72,6 +72,10 @@ func ActionableErr(phase Phase, err error) *proto.ActionableErr {
 }
 
 func ShowAIError(err error) error {
+	if IsSkaffoldErr(err) {
+		return err
+	}
+
 	var knownProblems = append(knownBuildProblems, knownDeployProblems...)
 	for _, v := range append(knownProblems, knownInitProblems...) {
 		if v.regexp.MatchString(err.Error()) {
@@ -100,6 +104,9 @@ func IsOldImageManifestProblem(err error) (string, bool) {
 }
 
 func getErrorCodeFromError(phase Phase, err error) (proto.StatusCode, []*proto.Suggestion) {
+	if t, ok := err.(Error); ok {
+		return t.StatusCode(), t.Suggestions()
+	}
 	if problems, ok := allErrors[phase]; ok {
 		for _, v := range problems {
 			if v.regexp.MatchString(err.Error()) {
@@ -118,6 +125,9 @@ func concatSuggestions(suggestions []*proto.Suggestion) string {
 		}
 		s.WriteString(suggestion.Action)
 	}
+	if s.String() == "" {
+		return ""
+	}
 	s.WriteString(".")
 	return s.String()
 }
