@@ -27,10 +27,13 @@ import (
 
 	sErrors "github.com/GoogleContainerTools/skaffold/pkg/skaffold/errors"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
+	schemautil "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
 	"github.com/GoogleContainerTools/skaffold/proto"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
+var targetPort = proto.IntOrString{Type: 0, IntVal: 2001}
+
 func TestGetLogEvents(t *testing.T) {
 	for step := 0; step < 1000; step++ {
 		ev := newHandler()
@@ -164,8 +167,14 @@ func TestPortForwarded(t *testing.T) {
 	handler.state = emptyState(latest.Pipeline{}, "test", true, true, true)
 
 	wait(t, func() bool { return handler.getState().ForwardedPorts[8080] == nil })
-	PortForwarded(8080, 8888, "pod", "container", "ns", "portname", "resourceType", "resourceName", "127.0.0.1")
-	wait(t, func() bool { return handler.getState().ForwardedPorts[8080] != nil })
+	PortForwarded(8080, schemautil.FromInt(8888), "pod", "container", "ns", "portname", "resourceType", "resourceName", "127.0.0.1")
+	wait(t, func() bool {
+		return handler.getState().ForwardedPorts[8080] != nil && handler.getState().ForwardedPorts[8080].RemotePort == 8888
+	})
+
+	wait(t, func() bool { return handler.getState().ForwardedPorts[8081] == nil })
+	PortForwarded(8081, schemautil.FromString("http"), "pod", "container", "ns", "portname", "resourceType", "resourceName", "127.0.0.1")
+	wait(t, func() bool { return handler.getState().ForwardedPorts[8081] != nil })
 }
 
 func TestStatusCheckEventStarted(t *testing.T) {
@@ -344,6 +353,7 @@ func TestResetStateOnBuild(t *testing.T) {
 				LocalPort:  2000,
 				RemotePort: 2001,
 				PodName:    "test/pod",
+				TargetPort: &targetPort,
 			},
 		},
 		StatusCheckState: &proto.StatusCheckState{Status: Complete},
@@ -379,6 +389,7 @@ func TestResetStateOnDeploy(t *testing.T) {
 				LocalPort:  2000,
 				RemotePort: 2001,
 				PodName:    "test/pod",
+				TargetPort: &targetPort,
 			},
 		},
 		StatusCheckState: &proto.StatusCheckState{Status: Complete},
@@ -422,6 +433,7 @@ func TestUpdateStateAutoTriggers(t *testing.T) {
 				LocalPort:  2000,
 				RemotePort: 2001,
 				PodName:    "test/pod",
+				TargetPort: &targetPort,
 			},
 		},
 		StatusCheckState: &proto.StatusCheckState{Status: Complete},
@@ -447,6 +459,7 @@ func TestUpdateStateAutoTriggers(t *testing.T) {
 				LocalPort:  2000,
 				RemotePort: 2001,
 				PodName:    "test/pod",
+				TargetPort: &targetPort,
 			},
 		},
 		StatusCheckState: &proto.StatusCheckState{Status: Complete},
