@@ -17,6 +17,7 @@ limitations under the License.
 package kubernetes
 
 import (
+	"context"
 	"fmt"
 
 	"github.com/sirupsen/logrus"
@@ -27,7 +28,7 @@ import (
 
 // TopLevelOwnerKey returns a key associated with the top level
 // owner of a Kubernetes resource in the form Kind-Name
-func TopLevelOwnerKey(obj metav1.Object, kind string) string {
+func TopLevelOwnerKey(ctx context.Context, obj metav1.Object, kind string) string {
 	for {
 		or := obj.GetOwnerReferences()
 		if or == nil {
@@ -35,7 +36,7 @@ func TopLevelOwnerKey(obj metav1.Object, kind string) string {
 		}
 		var err error
 		kind = or[0].Kind
-		obj, err = ownerMetaObject(obj.GetNamespace(), or[0])
+		obj, err = ownerMetaObject(ctx, obj.GetNamespace(), or[0])
 		if err != nil {
 			logrus.Warnf("unable to get owner from reference: %v", or[0])
 			return ""
@@ -43,7 +44,7 @@ func TopLevelOwnerKey(obj metav1.Object, kind string) string {
 	}
 }
 
-func ownerMetaObject(ns string, owner metav1.OwnerReference) (metav1.Object, error) {
+func ownerMetaObject(ctx context.Context, ns string, owner metav1.OwnerReference) (metav1.Object, error) {
 	client, err := kubernetesclient.Client()
 	if err != nil {
 		return nil, err
@@ -51,19 +52,19 @@ func ownerMetaObject(ns string, owner metav1.OwnerReference) (metav1.Object, err
 
 	switch owner.Kind {
 	case "Deployment":
-		return client.AppsV1().Deployments(ns).Get(owner.Name, metav1.GetOptions{})
+		return client.AppsV1().Deployments(ns).Get(ctx, owner.Name, metav1.GetOptions{})
 	case "ReplicaSet":
-		return client.AppsV1().ReplicaSets(ns).Get(owner.Name, metav1.GetOptions{})
+		return client.AppsV1().ReplicaSets(ns).Get(ctx, owner.Name, metav1.GetOptions{})
 	case "Job":
-		return client.BatchV1().Jobs(ns).Get(owner.Name, metav1.GetOptions{})
+		return client.BatchV1().Jobs(ns).Get(ctx, owner.Name, metav1.GetOptions{})
 	case "CronJob":
-		return client.BatchV1beta1().CronJobs(ns).Get(owner.Name, metav1.GetOptions{})
+		return client.BatchV1beta1().CronJobs(ns).Get(ctx, owner.Name, metav1.GetOptions{})
 	case "StatefulSet":
-		return client.AppsV1().StatefulSets(ns).Get(owner.Name, metav1.GetOptions{})
+		return client.AppsV1().StatefulSets(ns).Get(ctx, owner.Name, metav1.GetOptions{})
 	case "ReplicationController":
-		return client.CoreV1().ReplicationControllers(ns).Get(owner.Name, metav1.GetOptions{})
+		return client.CoreV1().ReplicationControllers(ns).Get(ctx, owner.Name, metav1.GetOptions{})
 	case "Pod":
-		return client.CoreV1().Pods(ns).Get(owner.Name, metav1.GetOptions{})
+		return client.CoreV1().Pods(ns).Get(ctx, owner.Name, metav1.GetOptions{})
 	default:
 		return nil, fmt.Errorf("kind %s is not supported", owner.Kind)
 	}
