@@ -17,15 +17,14 @@ limitations under the License.
 package defaults
 
 import (
-	"errors"
 	"testing"
 
 	"k8s.io/client-go/tools/clientcmd/api"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build/kaniko"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
-	kubectx "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/context"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
+	schemautil "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
@@ -309,96 +308,6 @@ func TestSetDefaultsOnLocalBuild(t *testing.T) {
 	testutil.CheckDeepEqual(t, 1, *cfg.Build.LocalBuild.Concurrency)
 }
 
-func TestSetDefaultPortForwardNamespace(t *testing.T) {
-	tests := []struct {
-		description        string
-		currentConfig      api.Config
-		currentConfigErr   error
-		cfg                *latest.SkaffoldConfig
-		expectedNamespaces []string
-	}{
-		{
-			description: "defined namespace",
-			currentConfig: api.Config{
-				CurrentContext: "cluster1",
-				Contexts: map[string]*api.Context{
-					"cluster1": {Namespace: "ns"},
-				},
-			},
-			cfg: &latest.SkaffoldConfig{
-				Pipeline: latest.Pipeline{
-					Build: latest.BuildConfig{},
-					PortForward: []*latest.PortForwardResource{
-						{
-							Type:      constants.Service,
-							Namespace: "mynamespace",
-						}, {
-							Type: constants.Service,
-						},
-					},
-				},
-			},
-			expectedNamespaces: []string{"mynamespace", "ns"},
-		},
-		{
-			description: "empty namespace",
-			currentConfig: api.Config{
-				CurrentContext: "cluster1",
-				Contexts: map[string]*api.Context{
-					"cluster1": {Namespace: ""},
-				},
-			},
-			cfg: &latest.SkaffoldConfig{
-				Pipeline: latest.Pipeline{
-					Build: latest.BuildConfig{},
-					PortForward: []*latest.PortForwardResource{
-						{
-							Type:      constants.Service,
-							Namespace: "mynamespace",
-						}, {
-							Type: constants.Service,
-						},
-					},
-				},
-			},
-			expectedNamespaces: []string{"mynamespace", "default"},
-		},
-		{
-			description:      "error getting context",
-			currentConfig:    api.Config{},
-			currentConfigErr: errors.New("ome error"),
-			cfg: &latest.SkaffoldConfig{
-				Pipeline: latest.Pipeline{
-					Build: latest.BuildConfig{},
-					PortForward: []*latest.PortForwardResource{
-						{
-							Type:      constants.Service,
-							Namespace: "mynamespace",
-						}, {
-							Type: constants.Service,
-						},
-					},
-				},
-			},
-			expectedNamespaces: []string{"mynamespace", "default"},
-		},
-	}
-
-	for _, test := range tests {
-		testutil.Run(t, test.description, func(t *testutil.T) {
-			kubectx.CurrentConfig = func() (api.Config, error) {
-				return test.currentConfig, test.currentConfigErr
-			}
-			err := Set(test.cfg)
-			t.CheckNoError(err)
-			t.CheckDeepEqual(len(test.expectedNamespaces), len(test.cfg.PortForward))
-			for i, pf := range test.cfg.PortForward {
-				t.CheckDeepEqual(test.expectedNamespaces[i], pf.Namespace)
-			}
-		})
-	}
-}
-
 func TestSetPortForwardLocalPort(t *testing.T) {
 	cfg := &latest.SkaffoldConfig{
 		Pipeline: latest.Pipeline{
@@ -406,10 +315,10 @@ func TestSetPortForwardLocalPort(t *testing.T) {
 			PortForward: []*latest.PortForwardResource{
 				{
 					Type: constants.Service,
-					Port: 8080,
+					Port: schemautil.FromInt(8080),
 				}, {
 					Type:      constants.Service,
-					Port:      8080,
+					Port:      schemautil.FromInt(8080),
 					LocalPort: 9000,
 				},
 			},
