@@ -341,7 +341,7 @@ func TestApplyProfiles(t *testing.T) {
 							Namespace: "ns",
 							Name:      "name",
 							Type:      "service",
-							Port:      8080,
+							Port:      util.FromInt(8080),
 							LocalPort: 8888,
 						}},
 					},
@@ -355,7 +355,7 @@ func TestApplyProfiles(t *testing.T) {
 					Namespace: "ns",
 					Name:      "name",
 					Type:      "service",
-					Port:      8080,
+					Port:      util.FromInt(8080),
 					LocalPort: 8888,
 				}),
 			),
