@@ -18,81 +18,90 @@ package trigger
 
 import (
 	"bytes"
+	"context"
+	"fmt"
 	"testing"
 	"time"
 
 	"github.com/google/go-cmp/cmp"
+	"github.com/rjeczalik/notify"
 
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner/runcontext"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
 func TestNewTrigger(t *testing.T) {
 	tests := []struct {
-		description string
-		opts        config.SkaffoldOptions
-		expected    Trigger
-		shouldErr   bool
+		description       string
+		trigger           string
+		watchPollInterval int
+		expected          Trigger
+		shouldErr         bool
 	}{
 		{
-			description: "polling trigger",
-			opts:        config.SkaffoldOptions{Trigger: "polling", WatchPollInterval: 1},
+			description:       "polling trigger",
+			trigger:           "polling",
+			watchPollInterval: 1,
 			expected: &pollTrigger{
 				Interval: 1 * time.Millisecond,
 			},
 		},
 		{
-			description: "notify trigger",
-			opts:        config.SkaffoldOptions{Trigger: "notify", WatchPollInterval: 1},
+			description:       "notify trigger",
+			trigger:           "notify",
+			watchPollInterval: 1,
 			expected: &fsNotifyTrigger{
 				Interval: 1 * time.Millisecond,
 				workspaces: map[string]struct{}{
 					"../workspace":            {},
 					"../some/other/workspace": {},
 				},
+				watchFunc: notify.Watch,
 			},
 		},
 		{
 			description: "manual trigger",
-			opts:        config.SkaffoldOptions{Trigger: "manual"},
+			trigger:     "manual",
 			expected:    &manualTrigger{},
 		},
 		{
 			description: "unknown trigger",
-			opts:        config.SkaffoldOptions{Trigger: "unknown"},
+			trigger:     "unknown",
 			shouldErr:   true,
 		},
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
-			runCtx := &runcontext.RunContext{
-				Opts: test.opts,
-				Cfg: latest.Pipeline{
-					Build: latest.BuildConfig{
-						Artifacts: []*latest.Artifact{
-							{
-								Workspace: "../workspace",
-							}, {
-								Workspace: "../workspace",
-							}, {
-								Workspace: "../some/other/workspace",
-							},
-						},
-					},
+			cfg := &mockConfig{
+				trigger:           test.trigger,
+				watchPollInterval: test.watchPollInterval,
+				artifacts: []*latest.Artifact{
+					{Workspace: "../workspace"},
+					{Workspace: "../workspace"},
+					{Workspace: "../some/other/workspace"},
 				},
 			}
 
-			got, err := NewTrigger(runCtx, nil)
+			got, err := NewTrigger(cfg, nil)
+
 			t.CheckError(test.shouldErr, err)
 			if !test.shouldErr {
-				t.CheckDeepEqual(test.expected, got, cmp.AllowUnexported(fsNotifyTrigger{}), cmp.AllowUnexported(manualTrigger{}), cmp.AllowUnexported(pollTrigger{}))
+				t.CheckDeepEqual(test.expected, got, cmp.AllowUnexported(fsNotifyTrigger{}), cmp.Comparer(ignoreFuncComparer), cmp.AllowUnexported(manualTrigger{}), cmp.AllowUnexported(pollTrigger{}))
 			}
 		})
 	}
 }
 
+func ignoreFuncComparer(x, y func(path string, c chan<- notify.EventInfo, events ...notify.Event) error) bool {
+	if x == nil && y == nil {
+		return true
+	}
+	if x == nil || y == nil {
+		return false
+	}
+	return true // cannot assert function equality, so skip
+}
+
 func TestPollTrigger_Debounce(t *testing.T) {
 	trigger := &pollTrigger{}
 	got, want := trigger.Debounce(), true
@@ -208,3 +217,55 @@ func TestManualTrigger_LogWatchToUser(t *testing.T) {
 		testutil.CheckDeepEqual(t, want, got)
 	}
 }
+
+func TestStartTrigger(t *testing.T) {
+	tests := []struct {
+		description string
+		trigger     Trigger
+	}{
+		{
+			description: "fsNotify trigger works",
+			trigger: &fsNotifyTrigger{
+				Interval:   200 * time.Millisecond,
+				workspaces: nil,
+				isActive:   func() bool { return false },
+				watchFunc: func(string, chan<- notify.EventInfo, ...notify.Event) error {
+					return nil
+				},
+			},
+		},
+		{
+			description: "fallback on polling trigger",
+			trigger: &fsNotifyTrigger{
+				Interval:   200 * time.Millisecond,
+				workspaces: nil,
+				isActive:   func() bool { return false },
+				watchFunc: func(string, chan<- notify.EventInfo, ...notify.Event) error {
+					return fmt.Errorf("failed to start watch trigger")
+				},
+			},
+		},
+	}
+
+	for _, test := range tests {
+		testutil.Run(t, test.description, func(t *testutil.T) {
+			_, err := StartTrigger(context.Background(), test.trigger)
+			time.Sleep(1 * time.Second)
+			t.CheckNoError(err)
+		})
+	}
+}
+
+type mockConfig struct {
+	trigger           string
+	watchPollInterval int
+	artifacts         []*latest.Artifact
+}
+
+func (c *mockConfig) Trigger() string        { return c.trigger }
+func (c *mockConfig) WatchPollInterval() int { return c.watchPollInterval }
+func (c *mockConfig) Pipeline() latest.Pipeline {
+	var pipeline latest.Pipeline
+	pipeline.Build.Artifacts = c.artifacts
+	return pipeline
+}
