@@ -82,7 +82,7 @@ func (t *T) CheckNotNil(actual interface{}) {
 }
 
 func isNil(actual interface{}) bool {
-	return actual == nil || (reflect.ValueOf(actual).Kind() == reflect.Ptr && reflect.ValueOf(actual).IsNil())
+	return actual == nil || (reflect.ValueOf(actual).Kind() == reflect.Ptr && reflect.ValueOf(actual).IsNil()) || (reflect.ValueOf(actual).Kind() == reflect.Func && reflect.ValueOf(actual).IsZero())
 }
 
 func (t *T) CheckTrue(actual bool) {
